/*========== Theme Darkblue ==========*/
.darkblue {
  background-color: #1d4e6d;
  color: #f7a92c;
}

.darkblue .toggler {
  background-color: #1d4e6d;
}

.darkblue a,
.darkblue a:hover,
.darkblue a:visited {
  color: #9cdd80;
}

.darkblue.bootsidemenu-left,
.darkblue.bootsidemenu-right,
.darkblue.bootsidemenu-left > .toggler,
.darkblue.bootsidemenu-right > .toggler {
  border-color: #44475a;
}

.darkblue .list-group-item.active,
.darkblue .list-group-item.active:focus,
.darkblue .list-group-item.active:hover,
.darkblue .item.active:focus {
  color: #44475a;
  background-color: #bed6ff;
  border-color: #bed6ff;
}

.darkblue a.list-group-item {
  color: #f7a92c;
}

.darkblue a.list-group-item:focus,
.darkblue a.list-group-item:hover,
.darkblue button.list-group-item:focus,
.darkblue button.list-group-item:hover {
  color: #44475a;
  text-decoration: none;
  background-color: #bed6ff;
  border-color: #bed6ff;
}

/*========== /Theme Darkblue ==========*/
