.bootsidemenu {
  z-index: 999999;
  position: fixed;
  top: -1px;
  bottom: -1px;
  padding: 0;
  background-color: #fff;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
}

.bootsidemenu > .menu-wrapper {
  padding: 0;
  position: absolute;
  bottom: 0;
  top: 0;
  overflow: auto;
  width: 100%;
}

.bootsidemenu > .row {
  margin: 0;
}

.bootsidemenu {
  /*width: auto;*/
  min-width: unset;
}

.bootsidemenu.bootsidemenu-left {
  left: 0;
  right: auto; /*20px;*/
}

.bootsidemenu.bootsidemenu-right {
  right: 0;
  left: auto; /*20px;*/
}

.toggler {
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.15);
  width: 20px;
  height: 48px;
  position: absolute;
  top: 47%;
  cursor: pointer;
  background-color: #fff;
}

.bootsidemenu-left > .toggler {
  -webkit-border-top-right-radius: 4px;
  -webkit-border-bottom-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  -moz-border-radius-bottomright: 4px;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  border-left: 1px solid #fff;
  -webkit-box-shadow: 1px 0 8px rgba(0, 0, 0, 0.175);
  box-shadow: 1px 0 8px rgba(0, 0, 0, 0.175);
  right: -20px;
}

.bootsidemenu-left > .toggler > span {
  margin: 15px 2px;
}

.bootsidemenu-right > .toggler {
  -webkit-border-top-left-radius: 4px;
  -webkit-border-bottom-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  -moz-border-radius-bottomleft: 4px;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
  border-right: 1px solid #fff;
  -webkit-box-shadow: -1px 0 8px rgba(0, 0, 0, 0.175);
  box-shadow: -1px 0 8px rgba(0, 0, 0, 0.175);
  left: -20px;
}

.bootsidemenu-right > .toggler > span {
  margin: 15px 2px;
}

/*Native BootStrap Hack*/
.bootsidemenu .list-group,
.bootsidemenu .list-group-item {
  background-color: transparent;
}

.bootsidemenu .list-group-item:last-child,
.bootsidemenu .list-group-item:first-child {
  border-radius: 0;
}

.bootsidemenu .list-group {
  margin-bottom: 0;
}

.bootsidemenu .list-group-item {
  border: 1px solid #ddd;
  border-left: 0;
  border-right: 0;
  margin-bottom: 0;
  margin-top: -1px;
}

.list-group .collapse a {
  padding-left: 25px;
}

.list-group-item .icon {
  margin-right: 5px;
}

/*==========  Media queries for test ==========*/

/* Custom, iPhone Retina */
@media only screen and (min-width: 320px) {
}

/* Extra Small Devices, Phones */
@media only screen and (min-width: 480px) {
}

/* Small Devices, Tablets */
@media only screen and (min-width: 768px) {
}

/* Medium Devices, Desktops */
@media only screen and (min-width: 992px) {
}

/* Large Devices, Wide Screens */
@media only screen and (min-width: 1200px) {
}

/*==========  Non-Mobile First Method  ==========*/

/* Large Devices, Wide Screens */
@media only screen and (max-width: 1200px) {
}

/* Medium Devices, Desktops */
@media only screen and (max-width: 992px) {
}

/* Small Devices, Tablets */
@media only screen and (max-width: 768px) {
  .bootsidemenu {
    min-width: 200px;
  }
}

/* Extra Small Devices, Phones */
@media only screen and (max-width: 480px) {
  .bootsidemenu {
    min-width: 90%;
  }
}

/* Custom, iPhone Retina */
@media only screen and (max-width: 320px) {
}

/*========== Theme Default ==========*/
.default {
  background-color: #ffffff;
  color: #555555;
}

.default .toggler {
  background-color: #ffffff;
}

.default a,
.default a:hover,
.default a:visited {
  color: #337ab7;
}

.default.bootsidemenu-left,
.default.bootsidemenu-right,
.default.bootsidemenu-left > .toggler,
.default.bootsidemenu-right > .toggler {
  border-color: rgba(0, 0, 0, 0.15);
}

.default.bootsidemenu-right > .toggler {
  border-right: 0;
}

.default.bootsidemenu-left > .toggler {
  border-left: 0;
}

.default .list-group-item.active,
.default .list-group-item.active:focus,
.default .list-group-item.active:hover,
.default .item.active:focus {
  color: #ffffff;
  background-color: #337ab7;
  border-color: #337ab7;
}

.default a.list-group-item {
  color: #555555;
}

.default a.list-group-item:focus,
.default a.list-group-item:hover,
.default button.list-group-item:focus,
.default button.list-group-item:hover {
  color: #ffffff;
  text-decoration: none;
  background-color: #337ab7;
  border-color: #337ab7;
}

/*========== Theme Default ==========*/
